@@ -26,37 +26,45 @@
 #                                                                                      #
 # ==================================================================================== #
 from yfrake.openapi.utils import get_spec_file_path
+from yfrake.server.utils import get_runtime_config
 from yfrake.server.utils import get_default_config
-from yfrake.server.helpers import build_route_table
-from yfrake.server.helpers import get_runtime_args
-from yfrake.server.helpers import create_swagger
-from yfrake.server.helpers import create_cors
-from yfrake.client.session import Session
+from yfrake.server.handler import handler
+from yfrake.server import helpers
+from yfrake import client
 from aiohttp import web
+import warnings
 import asyncio
-import sys
 
 
 # ==================================================================================== #
-async def main(config=None, run_forever=False):
-    config = config if config else get_default_config()
+if __name__ != '__main__':  # pragma: no branch
+    message = "\n" \
+        "╔═══════════════════════════════════════════════════╗\n" \
+        "║ The 'runner.py' file is not meant to be imported! ║\n" \
+        "║ Use 'from yfrake import server' instead! (YFrake) ║\n" \
+        "╚═══════════════════════════════════════════════════╝\n"
+    warnings.warn(message, category=RuntimeWarning, stacklevel=100)
 
-    app = web.Application()
+
+# ------------------------------------------------------------------------------------ #
+@client.configure()
+async def main(run_forever=False):
     spec = get_spec_file_path()
-    routes = build_route_table()
+    app = web.Application()
+    config = {
+        True: get_runtime_config,
+        False: get_default_config
+    }[run_forever]()
 
-    swagger = create_swagger(app, spec)
+    swagger = helpers.create_swagger(app, spec)
+    routes = [web.get('/{any}', handler)]
     swagger.add_routes(routes)
 
-    cors = create_cors(app)
+    cors = helpers.create_cors(app)
     routes = list(app.router.routes())
     for route in routes:
         cors.add(route)
 
-    await Session.a_open(
-        limit=config.limit,
-        timeout=config.timeout
-    )
     runner = web.AppRunner(app=app)
     await runner.setup()
 
@@ -64,27 +72,18 @@ async def main(config=None, run_forever=False):
         runner=runner,
         host=config.host,
         port=config.port,
-        backlog=config.backlog
-    )
+        backlog=config.backlog)
     await site.start()
+
+    helpers.print_notification(config.host, config.port)
     while run_forever:  # pragma: no cover
         await asyncio.sleep(3600)
 
     await site.stop()
     await runner.cleanup()
-    await Session.a_close()
 
 
 # ------------------------------------------------------------------------------------ #
 if __name__ == '__main__':
-    if sys.platform == 'win32':
-        asyncio.set_event_loop_policy(
-            asyncio.WindowsSelectorEventLoopPolicy()
-        )
-    args = dict(
-        config=get_runtime_args(),
-        run_forever=True
-    )
-    asyncio.run(
-        main(**args)
-    )
+    coro = main(run_forever=True)
+    asyncio.run(coro)
