@@ -25,22 +25,31 @@
 #    SOFTWARE.                                                                         #
 #                                                                                      #
 # ==================================================================================== #
-from . import runner, utils
+from . import utils
 import subprocess
 import psutil
 import sys
 
 
 # ==================================================================================== #
-class Server:
+class ServerSingleton:
     """
     This class contains methods to control
     the YFrake server programmatically.
     """
-    _err_msg_1 = 'YFrake server is already running!'
-    _err_msg_2 = 'Cannot stop YFrake server which is not running!'
+    # ------------------------------------------------------------------------------------ #
+    _err_msg_1 = 'Server is already running! (YFrake)'
+    _err_msg_2 = 'Cannot stop server which is not running! (YFrake)'
     _server: subprocess.Popen = None
     _is_running: bool = False
+    __instance__ = None
+
+    # Singleton pattern
+    # ------------------------------------------------------------------------------------ #
+    def __new__(cls):
+        if not cls.__instance__:
+            cls.__instance__ = super(ServerSingleton, cls).__new__(cls)
+        return cls.__instance__
 
     # ---------------------------------------------------------------------------------- #
     @classmethod
@@ -56,13 +65,15 @@ class Server:
             raise RuntimeError(cls._err_msg_1)
 
         settings = dict()
-        default = vars(utils.get_default_config())
+        default_config = vars(utils.get_default_config())
         for option in ['host', 'port', 'limit', 'timeout', 'backlog']:
-            value = kwargs.get(option, default[option])
+            value = kwargs.get(option, default_config[option])
             settings[option] = str(value)
+
+        runner_file_path = utils.get_runner_file_path()
         cls._server = subprocess.Popen(
             [
-                sys.executable, runner.__file__,
+                sys.executable, runner_file_path,
                 '--host', settings['host'],
                 '--port', settings['port'],
                 '--limit', settings['limit'],
@@ -79,8 +90,8 @@ class Server:
         try:
             parent = psutil.Process(cls._server.pid)
             children = parent.children(recursive=True)
-            for child in children:
-                child.kill()
-            parent.kill()
-        except psutil.NoSuchProcess:
+            procs = children + [parent]
+            for proc in procs:
+                proc.kill()
+        except psutil.NoSuchProcess:  # pragma: no cover
             return
