@@ -25,19 +25,24 @@
 #    SOFTWARE.                                                                         #
 #                                                                                      #
 # ==================================================================================== #
-from ..client.base_response import BaseResponse
+from argparse import ArgumentParser
 from multidict import MultiDictProxy
 from argparse import Namespace
 from pathlib import Path
 import configparser
-import json
 
 
 # ==================================================================================== #
+def get_runner_file_path() -> str:
+    runner_file = Path(__file__).with_name('runner.py').resolve()
+    return str(runner_file)
+
+
+# ------------------------------------------------------------------------------------ #
 def get_default_config() -> Namespace:
-    configfile = Path(__file__).with_name('server.ini')
+    config_file = Path(__file__).with_name('server.ini').resolve()
     config = configparser.ConfigParser()
-    config.read(configfile)
+    config.read(config_file)
     config = config['DEFAULT_SETTINGS']
     return Namespace(
         host=config['host'],
@@ -48,6 +53,18 @@ def get_default_config() -> Namespace:
     )
 
 
+# ------------------------------------------------------------------------------------ #
+def get_runtime_config() -> Namespace:  # pragma: no cover
+    config = get_default_config()
+    parser = ArgumentParser()
+    parser.add_argument('--host', type=str, default=config.host)
+    parser.add_argument('--port', type=int, default=config.port)
+    parser.add_argument('--limit', type=int, default=config.limit)
+    parser.add_argument('--timeout', type=int, default=config.timeout)
+    parser.add_argument('--backlog', type=int, default=config.backlog)
+    return parser.parse_args()
+
+
 # ------------------------------------------------------------------------------------ #
 def convert_multidict(multidict: MultiDictProxy) -> dict:
     out = dict()
@@ -55,14 +72,3 @@ def convert_multidict(multidict: MultiDictProxy) -> dict:
         if key not in out:
             out[key] = multidict[key]
     return out
-
-
-# ------------------------------------------------------------------------------------ #
-def pretty_json(resp: BaseResponse) -> str:
-    with resp.permissions:
-        obj = dict(
-            endpoint=resp.endpoint,
-            error=resp.error,
-            data=resp.data
-        )
-        return json.dumps(obj, indent=3)
